@@ -1,20 +1,13 @@
-# $Id: Cygwin.pm,v 1.3 2008/10/27 20:31:21 drhyde Exp $
+# $Id: Cygwin.pm,v 1.2 2007/10/19 16:45:51 drhyde Exp $
 
 package Devel::AssertOS::Cygwin;
 
 use Devel::CheckOS;
 
-$VERSION = '1.2';
+$VERSION = '1.1';
 
 sub os_is { $^O eq 'cygwin' ? 1 : 0; }
 
-sub expn {
-join("\n",
-"The operating system is Microsoft Windows, but perl was built using",
-"the POSIXish API provided by Cygwin"
-)
-}
-
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
