@@ -1,20 +1,13 @@
-# $Id: MSWin32.pm,v 1.3 2008/10/27 20:31:21 drhyde Exp $
+# $Id: MSWin32.pm,v 1.2 2007/10/19 16:45:52 drhyde Exp $
 
 package Devel::AssertOS::MSWin32;
 
 use Devel::CheckOS;
 
-$VERSION = '1.2';
+$VERSION = '1.1';
 
 sub os_is { $^O eq 'MSWin32' ? 1 : 0; }
 
-sub expn {
-join("\n",
-"The operating system is Microsoft Windows, and perl was built using",
-"the Win32 API"
-)
-}
-
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
